<?php
/**
 * This file is part of Part-DB (https://github.com/Part-DB/Part-DB-symfony).
 *
 * Copyright (C) 2019 - 2020 Jan Böhmer (https://github.com/jbtronics)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

declare(strict_types=1);

namespace App\Tests\Services\Misc;

use App\Services\Misc\FAIconGenerator;
use App\Tests\Services\AmountFormatter;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class FAIconGeneratorTest extends WebTestCase
{
    /**
     * @var FAIconGenerator
     */
    protected $service;

    protected function setUp(): void
    {
        parent::setUp(); // TODO: Change the autogenerated stub

        //Get an service instance.
        self::bootKernel();
        $this->service = self::getContainer()->get(FAIconGenerator::class);
    }

    public function fileExtensionDataProvider(): array
    {
        return [
            ['pdf', 'fa-file-pdf'],
            ['jpeg','fa-file-image'],
            ['txt', 'fa-file-lines'],
            ['doc', 'fa-file-word'],
            ['zip', 'fa-file-zipper'],
            ['png', 'fa-file-image'],
            ['jpg', 'fa-file-image'],
            ['gif', 'fa-file-image'],
            ['svg', 'fa-file-image'],
            ['xls', 'fa-file-excel'],
            ['xlsx', 'fa-file-excel'],
            ['ppt', 'fa-file-powerpoint'],
            ['pptx', 'fa-file-powerpoint'],
            ['docx', 'fa-file-word'],
            ['odt', 'fa-file-word'],
            ['ods', 'fa-file-excel'],
            ['odp', 'fa-file-powerpoint'],
            ['py', 'fa-file-code'],
            ['js', 'fa-file-code'],
            ['html', 'fa-file-code'],
            ['css', 'fa-file-code'],
            ['xml', 'fa-file-code'],
            ['json', 'fa-file-code'],
            ['yml', 'fa-file-code'],
            ['yaml', 'fa-file-code'],
            ['csv', 'fa-file-csv'],
            ['sql', 'fa-file-code'],
            ['sh', 'fa-file-code'],
            ['bat', 'fa-file-code'],
            ['exe', 'fa-file-code'],
            ['dll', 'fa-file-code'],
            ['lib', 'fa-file-code'],
            ['so', 'fa-file-code'],
            ['a', 'fa-file-code'],
            ['o', 'fa-file-code'],
            ['class', 'fa-file-code'],
            ['jar', 'fa-file-code'],
            ['rar', 'fa-file-zipper'],
            ['7z', 'fa-file-zipper'],
            ['tar', 'fa-file-zipper'],
            ['gz', 'fa-file-zipper'],
            ['tgz', 'fa-file-zipper'],
            ['bz2', 'fa-file-zipper'],
            ['tbz', 'fa-file-zipper'],
            ['xz', 'fa-file-zipper'],
            ['txz', 'fa-file-zipper'],
            ['zip', 'fa-file-zipper'],
            ['php', 'fa-file-code'],
            ['tmp', 'fa-file'],
            ['fgd', 'fa-file'],
        ];
    }

    /**
     * @dataProvider fileExtensionDataProvider
     */
    public function testFileExtensionToFAType(string $ext, string $expected): void
    {
        $this->assertSame($expected, $this->service->fileExtensionToFAType($ext), 'Failed for extension .'.$ext);
    }

    public function testGenerateIconHTML(): void
    {
        $this->assertSame('<i class="fa-solid fa-file "></i>', $this->service->generateIconHTML('fa-file'));
        $this->assertSame('<i class="far fa-file "></i>', $this->service->generateIconHTML('fa-file', 'far'));
        $this->assertSame('<i class="far fa-file fa-2x"></i>', $this->service->generateIconHTML('fa-file', 'far', 'fa-2x'));
    }
}
